using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;
using Syncfusion.Drawing;
using Syncfusion.Windows.Forms.Chart;

namespace ChartMetrics
{
    public partial class Form1 : Form
    {
        private DateTime startDate;
        private DateTime endDate;

        public Form1()
        {
            InitializeComponent();
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            AddChart();
        }

        private void AddChart()
        {
            ChartControl chart = new ChartControl();

            // Style the chart
            chart.Indexed = false;
            chart.CalcRegions = false;
            chart.SmoothingMode = SmoothingMode.HighQuality;
            chart.ChartAreaShadow = false;
            chart.Legend.Visible = false;
            chart.PrimaryXAxis.DrawGrid = false;
            chart.PrimaryYAxis.DrawGrid = false;
            chart.PrimaryXAxis.RangePaddingType = ChartAxisRangePaddingType.None;
            chart.PrimaryYAxis.RangePaddingType = ChartAxisRangePaddingType.None;
            chart.ShowToolTips = false;
            chart.ImprovePerformance = true;
            chart.DropSeriesPoints = true;
            
            chart.BackInterior = 
                new BrushInfo(GradientStyle.None, Color.White, Color.White);
            chart.ChartArea.BackInterior =
                new BrushInfo(GradientStyle.None, Color.White, Color.White);
            chart.ChartInterior = new BrushInfo(Color.White);
            chart.Anchor = AnchorStyles.Left | AnchorStyles.Top | AnchorStyles.Right;
            chart.EnableXZooming = true;

            ChartSeries series = chart.Model.NewSeries();

            // Style the series
            series.Type = ChartSeriesType.Line;
            series.EnableStyles = false;
            series.Style.DisplayShadow = false;

            // Add data
            AddData(series);

            // Style the x-axis after adding the series because the start and
            // end dates are set there
            chart.PrimaryXAxis.ValueType = ChartValueType.DateTime;
            chart.PrimaryXAxis.RangeType = ChartAxisRangeType.Set;
            //chart.PrimaryXAxis.DateTimeRange =
            //    new ChartDateTimeRange(startDate, endDate, 5, ChartDateTimeIntervalType.Seconds);
            chart.PrimaryXAxis.DateTimeRange =
                new ChartDateTimeRange(startDate, endDate, 1, ChartDateTimeIntervalType.Minutes);
            chart.PrimaryXAxis.DateTimeFormat = "mm:ss";
            chart.PrimaryXAxis.Font =
                new Font("Arial", 7F, FontStyle.Regular, GraphicsUnit.Point, 0);
            chart.PrimaryXAxis.LabelRotate = true;
            chart.PrimaryXAxis.LabelRotateAngle = 270;
            chart.PrimaryYAxis.Font = 
                new Font("Arial", 7F, FontStyle.Regular, GraphicsUnit.Point, 0);

            chart.Series.Add(series);

            this.tlpCharts.Controls.Add(chart);
        }

        private void AddData(ChartSeries series)
        {
            this.startDate = new DateTime(2006, 12, 8);
            Random random = new Random();
            for (Int32 i = 0; i < this.nudSeriesPoints.Value; i++)
            {
                // series.Points.Add(startDate.AddMilliseconds(i * 100), random.Next(0, 10));
                series.Points.Add(startDate.AddMilliseconds(i * 100), 100 * Math.Sin(i * Math.PI / 40));
            }
            this.endDate = startDate.AddMilliseconds((double)(this.nudSeriesPoints.Value - 1) * 100);
        }

        private void btnRemove_Click(object sender, EventArgs e)
        {
            if (this.tlpCharts.Controls.Count > 0)
            {
                this.tlpCharts.Controls.RemoveAt(this.tlpCharts.Controls.Count - 1);
            }
        }

        private void btnAddSeries_Click(object sender, EventArgs e)
        {
            if (this.tlpCharts.Controls.Count > 0)
            {
                ChartControl chart =
                    this.tlpCharts.Controls[this.tlpCharts.Controls.Count - 1] as ChartControl;
                if (chart != null)
                {
                    ChartSeries series = chart.Model.NewSeries();
                    series.Type = ChartSeriesType.StepLine;
                    AddData(series);
                    chart.Series.Add(series);
                }
            }
        }
    }
}